@@ -1,5 +1,3 @@
-from typing import Literal
-
 import astropy.units as u
 import ogameasure
 
@@ -13,19 +11,21 @@ class RHIO10(Attenuator):
 
     Identifier = "host"
 
-    def __init__(self) -> None:
+    def __init__(self, **kwargs) -> None:
         com = ogameasure.ethernet(self.Config.host, self.Config.port)
         self.io = ogameasure.SENA.adios(com)
 
-    def get_level(self, ch: Literal[1, 2]) -> u.Quantity:
+    def get_loss(self, id: str) -> u.Quantity:
+        ch = self.Config.channel[id]
         if ch == 1:
             return self.io.get_att1() << u.dB
         elif ch == 2:
             return self.io.get_att2() << u.dB
-        raise ValueError(f"Invalid channel number: {ch}")
+        raise ValueError(f"Invalid channel: {ch}")
 
-    def set_level(self, level_dB: int, ch: Literal[1, 2]) -> None:
-        self.io._set_att(ch, int(level_dB))
+    def set_loss(self, dB: int, id: str) -> None:
+        ch = self.Config.channel[id]
+        self.io._set_att(ch, int(dB))
 
     def finalize(self) -> None:
         self.io.com.close()
