@@ -1,5 +1,4 @@
 from abc import abstractmethod
-from typing import Literal
 
 import astropy.units as u
 
@@ -8,11 +7,11 @@ from ..device_base import DeviceBase
 
 class Encoder(DeviceBase):
 
-    # Manufacturer: str = ""
-    # Model: str
+    Manufacturer: str = ""
+    Model: str
 
     @abstractmethod
-    def get_reading(self, axis: Literal["az", "el"]) -> u.Quantity:
+    def get_reading(self) -> u.Quantity:
         ...
 
     @abstractmethod
