@@ -1,6 +1,7 @@
 import astropy.units as u
 import ogameasure
 
+from ...utils import busy
 from .vacuum_gauge_base import VacuumGauge
 
 
@@ -11,13 +12,14 @@ class TPG261(VacuumGauge):
 
     Identifier = "host"
 
-    def __init__(self):
+    def __init__(self, **kwargs):
         com = ogameasure.ethernet(self.Config.host, self.Config.port)
         self.io = ogameasure.Pfeiffer.tpg261_lan(com)
         self.io.pres_unit_pa()
 
     def get_pressure(self) -> u.Quantity:
-        return self.io.pressure() * u.Pa
+        with busy(self, "busy"):
+            return self.io.pressure() * u.Pa
 
     def finalize(self):
         self.io.com.close()
